;**********************************************************************
;   This file is a basic code template for assembly code generation   *
;   on the PIC16F627A. This file contains the basic code              *
;   building blocks to build upon.                                    *
;                                                                     *
;   Refer to the MPASM User's Guide for additional information on     *
;   features of the assembler (Document DS33014).                     *
;                                                                     *
;   Refer to the respective PIC data sheet for additional             *
;   information on the instruction set.                               *
;                                                                     *
;**********************************************************************
;                 JACKOLANTERN.asm                                           *
;    Date:        March 15 2015                                                  *
;    File Version:                                                    *
;                                                                     *
;    Author:         Ron Newton                                                 *
;    Company:                                                         *
;                                                              *
;**********************************************************************
;                                                                     *
;    Files Required: P16F627A.INC                                     *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Notes:                                                           *
;Pin 1		RA2		NC
;Pin 2		RA3		NC
;Pin 3		RA4		NC		
;Pin 4		RA5		NC
;Pin 5		VSS		NEGATIVE
;Pin 6		RB0		NC
;Pin 7		RB1		LED RESISTOR
;Pin 8		RB2		LED RESISTOR
;Pin 9		RB3		LED RESISTOR
;Pin 10		RB4		LED RESISTOR
;Pin 11		RB5		LED RESISTOR
;Pin 12		RB6		LED RESISTOR
;Pin 13		RB7		LED RESISTOR
;Pin 14		VCC		3 VOLTS +
;Pin 15		RA6		NC
;Pin 16		RA7		COLUMN 3 
;Pin 17		RA0		COLUMN 1 
;Pin 18     RA1     COLUMN 2                                                          *
;**********************************************************************

	list      p=16f627A           ; list directive to define processor
	#include <p16F627A.inc>       ; processor specific variable definitions

	errorlevel  -302              ; suppress message 302 from list file

	__CONFIG   _CP_OFF &  _LVP_OFF & _BOREN_OFF & _MCLRE_OFF & _WDT_OFF & _PWRTE_OFF & _INTOSC_OSC_NOCLKOUT 

; '__CONFIG' directive is used to embed configuration word within .asm file.
; The lables following the directive are located in the respective .inc file.
; See data sheet for additional information on configuration word settings.

#DEFINE		C1		PORTA,0
#DEFINE		C2		PORTA,1
#DEFINE		C3		PORTA,7
#DEFINE		AA		PORTB,1
#DEFINE		CC		PORTB,2
#DEFINE		DD		PORTB,3
#DEFINE		EE		PORTB,4
#DEFINE		FF		PORTB,5
#DEFINE		GG		PORTB,6
#DEFINE		HH		PORTB,7


	CBLOCK	0X20
COUNT		;COUNTING REGISTER
COUNT1		;COUNTING REGISTER
COUNT2		;COUNTING REGISTER
COUNT3		;COUNTING REGISTER
TIMER		;COUNTING REGISTER
TIMER1		;COUNTING REGISTER
TIMER2		;COUNTING REGISTER
TIMER3		;COUNTING REGISTER
TIMER4		;COUNTING REGISTER
COUNTER
FLAG
	ENDC




;**********************************************************************
	ORG     0x000             ; processor reset vector
	goto    main              ; go to beginning of program



main
		CLRF		PORTA		;CLEARPORTA
		CLRF		PORTB		;CLEAR PORTB
		BANKSEL		TRISA		;CHANGE BANKS
		CLRF		TRISA		;CLEAR TRISA	MAKE ALL OUTPUTS
		CLRF		TRISB		;CLEAR TRISB	
		BANKSEL		PORTA		;CHANGE BANKS
		MOVLW		0x07
		MOVWF		CMCON		;MAKE ALL PORTA DIGITAL
		BANKSEL		PCON		;CHANGE BANKS
		MOVLW		B'00001000'	;MOVE 8 INTO PCON
		MOVWF		PCON		;MAKE 4 mHZ
		MOVLW		B'00001111'	;LOAD 15
		MOVWF		OPTION_REG	;WATCH DOG TIMER MAXIMUM
		BANKSEL		PORTA
		
				
;**************************TESTING AREA****************
TEST
		MOVLW	.100
		MOVWF	TIMER1
		CALL	EYES
	
T12		CALL	CLEAR		;SMILE					
		BCF		C3
		BSF		AA			;#1
		CALL	CLEAR
		BCF		C3
		BSF		CC			;#2
		CALL	CLEAR
		BCF		C2
		BSF		AA			;#3
		CALL	CLEAR
		BCF		C1
		BSF		AA			;#4
		CALL	CLEAR
		BCF		C2
		BSF		CC			;#5
		CALL	CLEAR
		BCF		C1
		BSF		CC			;#6
		CALL	CLEAR
		BCF		C1
		BSF		HH			;#7
		CALL	CLEAR
		BCF		C2
		BSF		HH			;#8
		CALL	CLEAR		
		BCF		C3
		BSF		EE			;#9
		CALL	CLEAR
		BCF		C3
		BSF		HH			;#10
		CALL	CLEAR		
		BCF		C3
		BSF		FF			;#11
		CALL	CLEAR
		BCF		C1
		BSF		DD			;#12
		CALL	CLEAR
		BCF		C2
		BSF		GG			;#13
		CALL	CLEAR
		BCF		C3
		BSF		GG			;#14
		CALL	CLEAR
		BCF		C2
		BSF		FF			;15
		CALL	CLEAR		
		DECFSZ	TIMER,1
		GOTO	T12
	
		MOVLW	.100
		MOVWF	TIMER1
		CALL	EYES


						
T1		BCF		C3			;GRIMIS
		BSF		AA			;#1
		CALL	CLEAR
		BCF		C3
		BSF		CC			;#2
		CALL	CLEAR
		BCF		C2
		BSF		AA			;#3
		CALL	CLEAR
		BCF		C1
		BSF		AA			;#4
		CALL	CLEAR
		BCF		C2
		BSF		CC			;#5
		CALL	CLEAR
		BCF		C1
		BSF		CC			;#6
		CALL	CLEAR
		BCF		C1
		BSF		HH			;#7
		CALL	CLEAR
		BCF		C2
		BSF		HH			;#8
		CALL	CLEAR		
		BCF		C3
		BSF		EE			;#9
		CALL	CLEAR
		BCF		C2
		BSF		EE			;#18
		CALL	CLEAR		
		BCF		C2
		BSF		DD			;#16
		CALL	CLEAR
		BCF		C1
		BSF		FF			;#17
		CALL	CLEAR
		BCF		C2
		BSF		GG			;#13
		CALL	CLEAR
		BCF		C3
		BSF		GG			;#14
		CALL	CLEAR
		BCF		C1
		BSF		EE			;19
		CALL	CLEAR					
		DECFSZ	TIMER,1
		GOTO	T1

T13		BCF		C3			;SLANT TO RIGHT
		BSF		AA			;#1
		CALL	CLEAR
		BCF		C3
		BSF		CC			;#2
		CALL	CLEAR
		BCF		C2
		BSF		AA			;#3
		CALL	CLEAR
		BCF		C1
		BSF		AA			;#4
		CALL	CLEAR
		BCF		C2
		BSF		CC			;#5
		CALL	CLEAR
		BCF		C1
		BSF		CC			;#6
		CALL	CLEAR
		BCF		C1
		BSF		HH			;#7
		CALL	CLEAR
		BCF		C2
		BSF		HH			;#8
		CALL	CLEAR		
		BCF		C3
		BSF		EE			;#9
		CALL	CLEAR
		BCF		C2
		BSF		EE			;#18
		CALL	CLEAR		
		BCF		C2
		BSF		DD			;#16
		CALL	CLEAR
		BCF		C2
		BSF		FF			;#15
		CALL	CLEAR
		BCF		C2
		BSF		GG			;#13
		CALL	CLEAR
		BCF		C3
		BSF		GG			;#14
		CALL	CLEAR
		BCF		C3
		BSF		FF			;#11
		CALL	CLEAR					
		DECFSZ	TIMER,1
		GOTO	T13

T14		BCF		C3			;SLANT TO LEFT
		BSF		AA			;#1
		CALL	CLEAR
		BCF		C3
		BSF		CC			;#2
		CALL	CLEAR
		BCF		C2
		BSF		AA			;#3
		CALL	CLEAR
		BCF		C1
		BSF		AA			;#4
		CALL	CLEAR
		BCF		C2
		BSF		CC			;#5
		CALL	CLEAR
		BCF		C1
		BSF		CC			;#6
		CALL	CLEAR
		BCF		C1
		BSF		HH			;#7
		CALL	CLEAR
		BCF		C2
		BSF		HH			;#8
		CALL	CLEAR		
		BCF		C3
		BSF		EE			;#9
		CALL	CLEAR
		BCF		C3
		BSF		HH			;#10
		CALL	CLEAR		
		BCF		C1
		BSF		DD			;#12
		CALL	CLEAR
		BCF		C1
		BSF		FF			;#17
		CALL	CLEAR
		BCF		C2
		BSF		GG			;#13
		CALL	CLEAR
		BCF		C3
		BSF		GG			;#14
		CALL	CLEAR
		BCF		C1
		BSF		EE			;#19
		CALL	CLEAR					
		DECFSZ	TIMER,1
		GOTO	T14

		MOVLW	.25
		MOVWF	TIMER1
		CALL	EYES
				
T15		BCF		C3			;X LOOK
		BSF		AA			;#1
		CALL	CLEAR
		BCF		C3
		BSF		CC			;#2
		CALL	CLEAR
		BCF		C2
		BSF		AA			;#3
		CALL	CLEAR
		BCF		C1
		BSF		AA			;#4
		CALL	CLEAR
		BCF		C2
		BSF		CC			;#5
		CALL	CLEAR
		BCF		C1
		BSF		CC			;#6
		CALL	CLEAR
		BCF		C1
		BSF		HH			;#7
		CALL	CLEAR
		BCF		C2
		BSF		HH			;#8
		CALL	CLEAR		
		BCF		C3
		BSF		EE			;#9
		CALL	CLEAR
		BCF		C3
		BSF		HH			;#10
		CALL	CLEAR		
		BCF		C1
		BSF		DD			;#12
		CALL	CLEAR
		BCF		C1
		BSF		FF			;#17
		CALL	CLEAR
		BCF		C2
		BSF		GG			;#13
		CALL	CLEAR
		BCF		C3
		BSF		GG			;#14
		CALL	CLEAR
		BCF		C1
		BSF		EE			;#19
		CALL	CLEAR					
		BCF		C1
		BSF		DD			;#12
		CALL	CLEAR
		BCF		C1
		BSF		FF			;#17
		CALL	CLEAR
		BCF		C3
		BSF		FF			;#11
		CALL	CLEAR
		BCF		C2
		BSF		FF			;#15
		CALL	CLEAR
		BCF		C1
		BSF		EE			;#19
		CALL	CLEAR	
		BCF		C1
		BSF		DD			;#12
		CALL	CLEAR
		BCF		C2
		BSF		EE			;#18
		CALL	CLEAR
		BCF		C2
		BSF		DD			;#16
		CALL	CLEAR
		DECFSZ	TIMER,1
		GOTO	T15		

					
	GOTO	TEST

EYES
T0		MOVLW	.10
		MOVWF	TIMER
T2		BCF		C3
		BSF		AA			;#1
		CALL	CLEAR
		BCF		C1
		BSF		AA			;#4
		CALL	CLEAR
		BCF		C2
		BSF		AA			;#3
		CALL	CLEAR		
		DECFSZ	TIMER,1
		GOTO	T2	
		MOVLW	.10
		MOVWF	TIMER	
T3		BCF		C3
		BSF		CC			;#2
		CALL	CLEAR
		BCF		C2
		BSF		CC			;#5
		CALL	CLEAR
		BCF		C1
		BSF		CC			;#6
		CALL	CLEAR	
		DECFSZ	TIMER,1
		GOTO	T3
		DECFSZ	TIMER1,1
		GOTO	T0
		RETURN
;*******************************************************
		
CLEAR	DECFSZ		COUNTER,1
		GOTO		$-1
		MOVLW		B'10000011'
		MOVWF		PORTA
		CLRF		PORTB
		RETURN		
		
	END                       ; directive 'end of program'

